fnss.netconfig.nodeconfig.add_application — FNSS 0.1.0 documentation

### Navigation

- index
- modules |
- modules |
- next |
- previous |
- FNSS 0.1.0 documentation »
- API Reference »
- Functions »

# fnss.netconfig.nodeconfig.add_application

`add_application`(topology, node, name, properties)

  Add an application to a node

  Parameters : | topology : Topology The topology node : any hashable type The ID of the node name : str The name of the application properties : dict The properties of the application

### Navigation

- index
- modules |
- modules |
- next |
- previous |
- FNSS 0.1.0 documentation »
- API Reference »
- Functions »